package cn.com.ty.lift.business.project.service;

import cn.com.ty.lift.business.project.dao.entity.Project;
import cn.com.ty.lift.business.project.dao.entity.ProjectHistory;
import cn.com.ty.lift.business.project.dao.entity.model.ProjectHistoryRequest;
import cn.com.ty.lift.business.project.dao.entity.model.ProjectRequest;
import cn.com.ty.lift.business.project.dao.mapper.ProjectHistoryMapper;
import cn.com.ty.lift.business.project.dao.mapper.ProjectMapper;
import cn.com.ty.lift.common.base.ExportRequest;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.common.export.ExportUtils;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author bieao
 * @date 2019/11/28
 * @description 项目管理业务层
 */
@Service
public class ProjectService {

    @Resource
    private ProjectMapper projectMapper;

    @Resource
    private ProjectHistoryMapper projectHistoryMapper;

    private Map<String, String> paramMap = new HashMap<String, String>() {{
        put("projectCode", "项目编号");
        put("projectName", "项目名称");
        put("province", "省份");
        put("city", "市");
        put("district", "区");
        put("num", "台量");
        put("actualNum", "系统台量");
        put("address", "项目地址");
        put("startDate", "开始时间");
        put("endDate", "结束时间");
    }};

    /**
     * @param request 项目列表查询条件
     * @return RestResponse 结果集
     * @description 条件查询项目管理列表
     * @date 2019/11/27 2:10 PM
     */
    public RestResponse<IPage<Project>> list(ProjectRequest request) {
        IPage<Project> page = new Page<>(request.getPageNum(), request.getPageSize());
        List<Project> lifts = projectMapper.findByCondition(page, request);
        if (lifts.isEmpty()) {
            page.setRecords(new ArrayList<>());
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "暂无数据");
        }
        page.setRecords(lifts);
        return RestResponse.ok(page, ApiConstants.RESULT_SUCCESS, "查询列表成功");
    }

    /**
     * @param request 项目操作记录查询条件
     * @return RestResponse 结果集
     * @description 查询项目操作记录列表
     * @date 2019/11/27 2:10 PM
     */
    public RestResponse<IPage<ProjectHistory>> list(ProjectHistoryRequest request) {
        IPage<ProjectHistory> page = new Page<>(request.getPageNum(), request.getPageSize());
        List<ProjectHistory> historyList = projectHistoryMapper.selectByPrimaryKey(page, request);
        if (historyList.isEmpty()) {
            page.setRecords(new ArrayList<>());
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "暂无数据");
        }
        page.setRecords(historyList);
        return RestResponse.ok(page, ApiConstants.RESULT_SUCCESS, "查询列表成功");
    }

    /**
     * @param project 新增项目数据项
     * @return RestResponse 状态码和返回消息
     * @description 新增项目
     * @date 2019/11/27 2:22 PM
     */
    public RestResponse add(Project project) {
        Integer result = projectMapper.insertSelective(project);
        if (result > 0) {
            return RestResponse.ok(result, ApiConstants.RESULT_SUCCESS, "新增成功");
        }
        return RestResponse.error(ApiConstants.RESULT_ERROR, "新增失败");
    }

    /**
     * @param project 修改项目数据项
     * @return RestResponse 状态码和返回消息
     * @description 修改项目
     * @date 2019/11/27 2:22 PM
     */
    public RestResponse modify(Project project) {
        Integer result = projectMapper.updateByPrimaryKeySelective(project);
        if (result > 0) {
            return RestResponse.ok(result, ApiConstants.RESULT_SUCCESS, "修改成功");
        }
        return RestResponse.error(ApiConstants.RESULT_ERROR, "修改失败");
    }

    /**
     * @param request 导出项目数据列表
     * @return RestResponse 状态码和返回消息
     * @description 导出项目
     * @date 2019/11/27 2:22 PM
     */
    public void export(ExportRequest request) {
        List<Project> projectList = projectMapper.selectBatchIds(request.getIds());
        ExportUtils utils = new ExportUtils();
        utils.export(projectList, paramMap, request.getExportPath());
    }
}
